@@ -1,7 +1,7 @@
 var searchData=
 [
   ['queries_20for_20dpi_20aware_20rendering_0',['Content scale queries for DPI-aware rendering',['../news.html#content_scale_33',1,'']]],
-  ['query_1',['query',['../news.html#geterror_33',1,'Error query'],['../news.html#news_31_framesize',1,'Window frame size query'],['../news.html#news_30_wndpos',1,'Window position query']]],
+  ['query_1',['Query',['../news.html#geterror_33',1,'Error query'],['../news.html#news_31_framesize',1,'Window frame size query'],['../news.html#news_30_wndpos',1,'Window position query']]],
   ['query_20for_20the_20monitor_20work_20area_2',['Query for the monitor work area',['../news.html#workarea_33',1,'']]],
   ['query_20for_20the_20scancode_20of_20a_20key_3',['Query for the scancode of a key',['../news.html#key_scancode_33',1,'']]],
   ['querying_20for_20vulkan_20presentation_20support_4',['Querying for Vulkan presentation support',['../vulkan_guide.html#vulkan_present',1,'']]],
