@@ -3,8 +3,8 @@ var searchData=
   ['key_0',['Query for the scancode of a key',['../news.html#key_scancode_33',1,'']]],
   ['key_20bit_20masks_1',['Modifier key bit masks',['../news.html#news_30_keymods',1,'']]],
   ['key_20flags_2',['Modifier key flags',['../group__mods.html',1,'']]],
-  ['key_20input_3',['key input',['../input_guide.html#input_key',1,'Key input'],['../moving_guide.html#moving_keys',1,'Physical key input']]],
-  ['key_20names_4',['key names',['../input_guide.html#input_key_name',1,'Key names'],['../news.html#news_32_keyname',1,'Localized key names']]],
+  ['key_20input_3',['Key input',['../input_guide.html#input_key',1,'Key input'],['../moving_guide.html#moving_keys',1,'Physical key input']]],
+  ['key_20names_4',['Key names',['../input_guide.html#input_key_name',1,'Key names'],['../news.html#news_32_keyname',1,'Localized key names']]],
   ['key_20repeat_20action_5',['Key repeat action',['../moving_guide.html#moving_repeat',1,'']]],
   ['key_20tokens_6',['Keyboard key tokens',['../group__keys.html',1,'']]],
   ['keyboard_20input_7',['Keyboard input',['../input_guide.html#input_keyboard',1,'']]],
